===========
Expressions
===========

This page gives an overview of all public polars expressions.

.. toctree::
   :maxdepth: 2
   :hidden:

   aggregation
   array
   binary
   boolean
   categories
   columns
   computation
   functions
   modify_select
   meta
   miscellaneous
   strings
   struct
   timeseries
   window

.. currentmodule:: polars

.. autoclass:: Expr
    :members:
    :noindex:
    :autosummary:
    :autosummary-nosignatures:
